import { ID } from '../../common';
import { CommitChange } from './change';
import { Error } from './error';
export declare type Message = {
    packetType: string;
    data?: unknown;
};
/**
 * Socket.io packet types
 *
 * e.g.
 *  - onmessage 40{"sid":"mAsOl9ZNGQ8vRWA_AABt"}
 *  - onmessage 42["graceful-shutdown"]
 *
 * @see https://github.com/socketio/engine.io-protocol
 * @see https://github.com/socketio/socket.io-parser/blob/master/lib/index.ts
 */
export declare const packetTypes: {
    readonly open: "0";
    readonly close: "1";
    readonly ping: "2";
    readonly pong: "3";
    readonly message: "4";
    readonly connectedMessage: "40";
    readonly errorMessage: "41";
    readonly updateMessage: "42";
    readonly responseMessage: "43";
};
export declare type CursorMessagePayload = [
    'cursor',
    {
        user: {
            id: string;
            displayName: string;
        };
        pageId: string;
        position: {
            line: number;
            char: number;
        };
        visible: true;
        socketId: string;
    }
];
export declare type ExternalCommitMessagePayload = [
    'commit',
    {
        kind: 'page';
        parentId: string;
        changes: CommitChange[];
        cursor: null;
        pageId: string;
        userId: ID;
        projectId: string;
        freeze: true;
        id: string;
    }
];
export declare type InitializedMessage = {
    packetType: typeof packetTypes.open;
    data: {
        sid: string;
        upgrades: [];
        pingInterval: number;
        pingTimeout: number;
    };
};
export declare type ConnectedMessage = {
    packetType: typeof packetTypes.connectedMessage;
    data: {
        sid: string;
    };
};
export declare type CommitResultMessage = {
    packetType: `${typeof packetTypes.responseMessage}${number}`;
    data: ({
        data: {
            commitId: string;
        };
    } | {
        error: Error;
    })[];
};
export declare type JoinResultMessage = {
    packetType: `${typeof packetTypes.responseMessage}${number}`;
    data: ({
        data: {
            success: true;
            pageId: string;
            projectId: string;
        };
    } | {
        error: Error;
    })[];
};
export declare type ResponseMessage = CommitResultMessage | JoinResultMessage;
export declare const isResponseMessageOf: <M extends ResponseMessage>(id: string | number) => (message: Message) => message is M;
export declare const isInitializedMessage: (message: Message) => message is InitializedMessage;
export declare const isConnectedMessage: (message: Message) => message is ConnectedMessage;
