'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var blockNodes = require('./block-nodes.js');
var functions = require('./functions.js');

const parseLines = lines => {
  return functions.threewiseMap(lines.map(line => ({ ...line,
    ...blockNodes.parseBlockNode(line.text)
  })), (curr, prev, next, index) => {
    const data = { ...curr
    }; // add line number

    data.number = index + 1; // add title

    if (index === 0) {
      data.title = true;
      data.nodes = undefined;
    } // add section


    data.section = {
      number: prev === undefined ? 0 : prev.section.end ? prev.section.number + 1 : prev.section.number,
      start: prev === undefined || prev.section.end,
      end: next === undefined || curr.empty && !next.empty
    }; // add codeBlock

    if (curr.codeBlock) {
      data.codeBlock = { ...curr.codeBlock,
        indent: curr.indent,
        start: true,
        end: !next || !(curr.indent < next.indent)
      };
    } else if (prev !== null && prev !== void 0 && prev.codeBlock && !prev.codeBlock.end && prev.codeBlock.indent < curr.indent) {
      data.codeBlock = { ...prev.codeBlock,
        start: false,
        end: !next || !(prev.codeBlock.indent < next.indent)
      };
      data.nodes = undefined;
    } // add tableBlock


    if (curr.tableBlock) {
      data.tableBlock = { ...curr.tableBlock,
        indent: curr.indent,
        start: true,
        end: !next || !(curr.indent < next.indent)
      };
    } else if (prev !== null && prev !== void 0 && prev.tableBlock && !prev.tableBlock.end && prev.tableBlock.indent < curr.indent) {
      data.tableBlock = { ...prev.tableBlock,
        start: false,
        end: !next || !(prev.tableBlock.indent < next.indent)
      };
      data.nodes = undefined;
    }

    return data;
  });
};

exports.parseLines = parseLines;
//# sourceMappingURL=parser.js.map
