'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var rxjs = require('rxjs');

const historyState = (w = window) => {
  return new rxjs.Observable(subscriber => {
    const originPushState = w.history.pushState;
    const originReplaceState = w.history.replaceState;

    const patchedPushState = (state, title, url) => {
      // NOTE: to avoid `TypeError: Illegal invocation`
      originPushState.call(w.history, state, title, url);
      subscriber.next(w.location.href);
    };

    const patchedReplaceState = (state, title, url) => {
      // NOTE: to avoid `TypeError: Illegal invocation`
      originReplaceState.call(w.history, state, title, url);
      subscriber.next(w.location.href);
    };

    const onPopstate = () => subscriber.next(w.location.href);

    w.history.pushState = patchedPushState.bind(w.history);
    w.history.replaceState = patchedReplaceState.bind(w.history);
    w.addEventListener('popstate', onPopstate);
    return () => {
      w.history.pushState = originPushState;
      w.history.replaceState = originReplaceState;
      w.removeEventListener('popstate', onPopstate);
    };
  });
};

exports.historyState = historyState;
//# sourceMappingURL=history-state.js.map
