import { RestApi } from './rest-api/rest-api.js';
import { WebsocketClient } from './websocket/websocket-client.js';

class ScrapboxApi {
    restApi;
    websocketHandler;
    constructor(token = '', debug = false, restApi = new RestApi(token), websocketHandler = new WebsocketClient({ token, debug })) {
        this.restApi = restApi;
        this.websocketHandler = websocketHandler;
    }
    async getPage(projectName, pageName) {
        return this.restApi.getPage(projectName, pageName);
    }
    async changeLine(projectName, pageName, change) {
        const project = await this.getProject(projectName);
        const { pageId, commitId } = await this.getPageIdAndCommitId(projectName, pageName);
        await this.commit({
            changes: Array.isArray(change) ? change : [change],
            projectId: project.id,
            pageId: pageId,
            commitId: commitId,
        });
    }
    async getUser() {
        return await this.restApi.getMe();
    }
    closeConnection() {
        this.websocketHandler.close();
    }
    async getProject(projectName) {
        return await this.restApi.getProject(projectName);
    }
    async getPageIdAndCommitId(projectName, pageName) {
        const page = await this.restApi.getPage(projectName, pageName);
        return { pageId: page.id, commitId: page.commitId };
    }
    async commit(param) {
        const user = await this.getUser();
        return this.websocketHandler.commit({
            userId: user.id,
            projectId: param.projectId,
            pageId: param.pageId,
            parentId: param.commitId,
            changes: param.changes,
        });
    }
}

export { ScrapboxApi };
//# sourceMappingURL=scrapbox-api.js.map
