/**
 * Socket.io packet types
 *
 * e.g.
 *  - onmessage 40{"sid":"mAsOl9ZNGQ8vRWA_AABt"}
 *  - onmessage 42["graceful-shutdown"]
 *
 * @see https://github.com/socketio/engine.io-protocol
 * @see https://github.com/socketio/socket.io-parser/blob/master/lib/index.ts
 */
const packetTypes = {
    open: '0',
    close: '1',
    ping: '2',
    pong: '3',
    message: '4',
    connectedMessage: '40',
    errorMessage: '41',
    // both send and receive cursor message: 42["cursor",{"user":{"id":"...
    // receive graceful-shutdown message: 40{"sid":"mAsOl9ZNGQ8vRWA_AABt"}
    updateMessage: '42',
    responseMessage: '43',
};
const getRequestId = (type) => type.slice(2);
const isResponseMessageOf = (id) => {
    return (message) => {
        return message.packetType.startsWith(packetTypes.responseMessage) && getRequestId(message.packetType) === String(id);
    };
};
const isInitializedMessage = (message) => {
    return message.packetType === packetTypes.open;
};
const isConnectedMessage = (message) => {
    return message.packetType === packetTypes.connectedMessage;
};

export { isConnectedMessage, isInitializedMessage, isResponseMessageOf, packetTypes };
//# sourceMappingURL=message.js.map
