import { ReplaySubject, firstValueFrom } from 'rxjs';
import { UserScriptApi } from '../user-script/scrapbox.js';

const concatPageLines = (lines) => {
    const [, ...contentsLines] = lines; // drop first title line
    return contentsLines.map(({ text }) => text).join('');
};
class DynamicConfig {
    api;
    data$ = new ReplaySubject(1);
    get data() {
        return firstValueFrom(this.data$);
    }
    constructor(api) {
        this.api = api;
        this.#loadConfig().catch(console.error);
    }
    async #loadConfig() {
        let config = {};
        try {
            const page = await this.api.getPage(UserScriptApi.projectName, 'config');
            const json = concatPageLines(page.lines);
            config = JSON.parse(json);
        }
        catch (e) {
            console.error(e);
        }
        this.data$.next({ ...config });
    }
}

export { DynamicConfig };
//# sourceMappingURL=dynamic-config.js.map
