import { isString } from './functions.js';
import { parseInlineNodes } from './inline-nodes.js';

const indentRegexp = '^(?<indent>\\s*)';
const codeBlockRegexp = '(?<codeBlock>code:(?<codeBlockFileName>(?:[^.]+$)|(?:.*(?<codeBlockLang>\\.\\S+$(?!\\..+)))))';
const tableBlockRegexp = '(?<tableBlock>table:(?<tableBlockTitle>.+))';
const cliRegexp = '(?<cli>(?<cliPrefix>[$%]) (?<cliCommand>.+))';
const textRegexp = '(?<text>.*)';
const parseLineRegexp = new RegExp(`${indentRegexp}(${[codeBlockRegexp, tableBlockRegexp, cliRegexp, textRegexp].join('|')})`, 'gu');
const parseBlockNode = (text) => {
    const result = [...text.matchAll(parseLineRegexp)].map((match) => match.groups)[0];
    const indent = result.indent.length;
    const empty = /^\s*$/.test(text); // i.e. '', ' ', '  ', ...
    switch (true) {
        case isString(result.codeBlock): {
            return {
                indent,
                empty,
                codeBlock: {
                    filename: result.codeBlockFileName,
                    lang: result.codeBlockLang ?? '',
                },
            };
        }
        case isString(result.tableBlock): {
            return {
                indent,
                empty,
                tableBlock: {
                    title: result.tableBlockTitle,
                    cells: [],
                },
            };
        }
        case isString(result.cli): {
            return {
                indent,
                empty,
                cli: {
                    prefix: result.cliPrefix,
                    command: result.cliCommand,
                },
            };
        }
        case isString(result.text): {
            return {
                indent,
                empty,
                nodes: result.indent.length === 0
                    ? parseInlineNodes(result.text)
                    : {
                        type: 'indent',
                        unit: {
                            content: result.text,
                            tag: result.indent,
                            whole: text,
                        },
                        children: parseInlineNodes(result.text),
                    },
            };
        }
        default: {
            throw new Error('unreachable');
        }
    }
};

export { parseBlockNode };
//# sourceMappingURL=block-nodes.js.map
